InvokeEndLengthResult

Enum InvokeEndLengthResult 

pub enum InvokeEndLengthResult<'invoker> {
    Done(Result<(usize, MethodCall<'invoker>), MethodCallError<'invoker>>),
    Pending(MethodCall<'invoker>),
}
The result of a call to end_length.

The 'invoker lifetime parameter is the lifetime of the method invoker that is performing the call.

Variants



Done(Result<(usize, MethodCall<'invoker>), MethodCallError<'invoker>>)

The method call is complete. If the method call completed successfully, the Result value contains both the length of the call result, in bytes, and the MethodCall value that can be used to fetch the result if desired. If the method call failed, the Result value contains the error.



Pending(MethodCall<'invoker>)

The method call is not finished yet. The MethodCall value is returned so the caller can continue to monitor progress.