pub enum InvokeResult {
Complete,
Incomplete,
}Expand description
The possible results of a successful start to a method call.
Variants
Complete
The method is complete and its result can be fetched immediately.
Incomplete
The method is not finished yet; its result can be fetched on the next timeslice.