pub enum MethodCallError<'invoker> {
CborDecode,
BufferTooShort,
NoSuchComponent,
NoSuchMethod,
BadParameters(LastException<'invoker>),
QueueFull,
QueueEmpty,
BadDescriptor,
TooManyDescriptors,
Other(LastException<'invoker>),
Unknown,
}Expand description
The possible errors that could occur during a method call.
Some errors carry additional information. This information is only available until the start of
the next method call. The 'invoker lifetime ensures that the invoker cannot be reused to
start another method call until a value of this type is dropped and therefore the additional
error information is no longer accessible.
Variants
CborDecode
BufferTooShort
NoSuchComponent
NoSuchMethod
BadParameters(LastException<'invoker>)
QueueFull
QueueEmpty
BadDescriptor
TooManyDescriptors
Other(LastException<'invoker>)
Unknown
Implementations