MethodListing

Struct MethodListing 

pub struct MethodListing<'lister>(/* private fields */);

Implementations

Source

impl MethodListing<'_>

pub fn next_len(&self) -> Option<NonZeroUsize>

Returns the length, in bytes, of the name of the next method in the list of methods.

If there is no next entry, None is returned.

Panics

This function panics if the underlying syscall fails, because the only reasons it could fail should be impossible due to the type system.

pub fn next<'buffer>( &mut self, buffer: &'buffer mut [u8], ) -> Result<Option<(&'buffer mut str, MethodAttributes)>>

Returns the next method in the list of methods.

The buffer parameter identifies where to store the next method name.

If there is a next method, its name is written to buffer, a string slice referring to the name along with the attributes are returned, and the iteration is advanced. If not, None is returned.

Errors
  • BufferTooShort is returned if buffer is not large enough to hold the method name.

On error, the iteration does not advance.