Bytes

Struct Bytes 

pub struct Bytes<'a>(/* private fields */);
A reference to a byte array.

Implementations

Source

impl<'a> Bytes<'a>

pub const unsafe fn new(data: &'a [u8]) -> Self

Wraps a byte array in a byte-array external reference.

Safety

It is not actually unsafe to construct a Bytes object. However, if the caller then CBOR-encodes the resulting object, they must ensure that the Bytes object remains in existence until the CBOR data has been submitted as part of a method call. Failure to do this would allow the referent to be modified or dropped, resulting in OC-Wasm reading from that reused memory.